package ristinolla;

import java.net.URL;
import java.util.ResourceBundle;

import fi.jyu.mit.fxgui.StringGrid;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.TextArea;
import javafx.scene.input.KeyCode;

/**
 * Yksikertaistettu risitinolla. 
 * Vuorossa oleva pelaaja näytetään otsikko-rivin 0-sarakkeessa.
 * Alueen oikean reunaan näytetään siirtohistoria
 * @author vesal
 * @version 26.3.2016
 */
public class RistiNollaController implements Initializable {
    @FXML private StringGrid<Object> grid;
    @FXML private TextArea area;
    private int vuorossa = 0;
    private int koko = 8;
    private String[] merkit = {"X", "O"};
    private String[] tyylit = {"risti", "nolla"};
    
    
    @Override
    public void initialize(URL location, ResourceBundle resources) {
        //grid.setEmptyStyleClass("valkoinen"); // tyhjät solut valkoiseksi // voi hoitaa css:llä
        grid.getSelectionModel().setCellSelectionEnabled(true); // yksittäinen solu voidaan valita
        String[] headings = new String[koko+1];
        String[] tyhja = new String[koko+1];
        headings[0] = "";
        for (int i=1; i<=koko; i++) headings[i] = ""+i;
        grid.initTable(headings); // Alustetaan otsikot juoksevilla numeroilla
        for (int i=0; i<koko+1; i++) tyhja[i] = "";
        
        grid.setColumnWidth(-1,30);   // sarakkeet kapeammiksi
        grid.setSortable(-1, false);  // järjestäminen ei ole mielekästä
        grid.disableColumnReOrder();
        
        for (int i=1; i<=koko; i++) { // lisätään rivinumero ja rivit
            tyhja[0] = ""+i;
            grid.add(tyhja);
            grid.setStyleClass("otsikko", i-1, 0);
        }
            
        naytaVuorossa();
        
        grid.setOnMouseClicked( e -> laitaMerkki() );
        grid.setOnKeyPressed( e -> {if ( e.getCode() == KeyCode.ENTER ) laitaMerkki();});
    }
    

    private void laitaMerkki() {
        int r = grid.getRowNr();
        int c = grid.getColumnNr();
        if ( r < 0 || c < 1 ) return; // otsikkoon ei saa klikata
        if ( !grid.get(r, c).isEmpty() ) return; // vain tyhjään saa laittaa
        grid.setStyleClass(tyylit[vuorossa], r, c);
        String merkki = merkit[vuorossa];
        grid.set(merkki, r, c);
        area.setText(area.getText() + String.format("%s -> (%d,%d)\n", merkki, r+1, c));
        vuorossa = (vuorossa+1) % merkit.length;
        naytaVuorossa();
    }

    
    private void naytaVuorossa() {
        grid.getColumns().get(0).setText(merkit[vuorossa]);
    }
    
}